Module args

Module args 

Shared arguments to create a world.

Structs

CompileFontArgs
The font arguments for the world.
CompileOnceArgs
Common arguments of compile, watch, and query.
CompilePackageArgs
Arguments related to where packages are stored in the system.

Enums

ExportTarget
Specifies the current export target.
Feature
An in-development feature that may be changed or removed at any time.
OutputFormat
Which format to use for the generated output file.
PdfStandard
A PDF standard that Typst can enforce conformance with.
TaskWhen
When to export an output file.

Functions

parse_source_date_epoch
Parses a UNIX timestamp according to https://reproducible-builds.org/specs/source-date-epoch/