pub struct CompileOnceArgs {
pub input: Option<String>,
pub root: Option<PathBuf>,
pub font: CompileFontArgs,
pub package: CompilePackageArgs,
pub pdf: PdfExportArgs,
pub png: PngExportArgs,
pub features: Vec<Feature>,
pub inputs: Vec<(String, String)>,
pub creation_timestamp: Option<i64>,
pub cert: Option<PathBuf>,
}Expand description
Common arguments to create a world (environment) to run typst tasks, e.g.
compile, watch, and query.
Fields
input: Option<String>Specify the path to input Typst file. If the path is relative, it will be resolved relative to the current working directory (PWD).
root: Option<PathBuf>Configure the project root (for absolute paths).
font: CompileFontArgsSpecify the font related arguments.
package: CompilePackageArgsSpecify the package related arguments.
pdf: PdfExportArgsSpecify the PDF export related arguments.
png: PngExportArgsSpecify the PNG export related arguments.
features: Vec<Feature>Enable in-development features that may be changed or removed at any time.
inputs: Vec<(String, String)>Add a string key-value pair visible through sys.inputs.
Examples
Tell the script that sys.inputs.foo is "bar" (type: str).
tinymist compile --input foo=barcreation_timestamp: Option<i64>Configure the document’s creation date formatted as a UNIX timestamp (in seconds).
For more information, see https://reproducible-builds.org/specs/source-date-epoch/.
cert: Option<PathBuf>Specify the path to CA certificate file for network access, especially for downloading typst packages.
Implementations
Sourceimpl CompileOnceArgs
impl CompileOnceArgs
Sourcepub fn resolve_features(&self) -> Features
pub fn resolve_features(&self) -> Features
Resolves the features.
Sourcepub fn resolve_inputs(&self) -> Option<ImmutDict>
pub fn resolve_inputs(&self) -> Option<ImmutDict>
Resolves the inputs.
Sourcepub fn resolve_sys_entry_opts(&self) -> Result<EntryOpts>
pub fn resolve_sys_entry_opts(&self) -> Result<EntryOpts>
Resolves the entry options.
Sourceimpl CompileOnceArgs
impl CompileOnceArgs
Sourcepub fn resolve_system(&self) -> Result<TypstSystemUniverse>
pub fn resolve_system(&self) -> Result<TypstSystemUniverse>
Resolves the arguments into a system universe. This is also a sample implementation of how to resolve the arguments (user inputs) into a universe.